"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MSGS = void 0;
exports.MSGS = {
    PAGE_NOT_SUGGEST: 'No page with given title suggested : ',
    PAGE_NOT_EXIST: 'No page with given title exists : ',
    INFOBOX_NOT_EXIST: 'Info cannot be parsed for given page',
    INVALID_WIKIPEDIA_URL: 'The provided URL is invalid or does not belong to Wikipedia - ',
};
