import { pageOptions } from ".";
export declare function isString(title: any): boolean;
export declare function setTitleForPage(title: string, pageOptions?: pageOptions): Promise<string>;
export declare function setPageIdOrTitleParam(params: any, title: string): any;
export declare function setPageId(params: any, results: any): number;
export declare function getCurrentYear(): number;
export declare function getCurrentMonth(): number;
export declare function getCurrentDay(): number;
